@@ -25,13 +25,12 @@
 #'
 #' @method as.data.frame netconnection 
 #' @export
-#' @export as.data.frame.netconnection
 
 
 as.data.frame.netconnection <- function(x, ...){
   
   
-  meta:::chkclass(x, "netconnection")
+  chkclass(x, "netconnection")
   
   
   ## Drop unnecessary list elements
